#include "geminc.h"
#include "gemprm.h"
#include "macmn.h"

/*
**  Function prototypes.
*/

void ma_icpt( char [][8], char[][8], int * );

char *outstr( char [] );


/************************************************************************
 * ma_icpt                                                              *
 *                                                                      *
 * This routine prints the interface values arrays to the decoder log   *
 * if the verbosity level is 3 or higher.                               *
 *                                                                      *
 * ma_icpt ( rimnem, cimnem, *iret )                                    *
 *                                                                      *
 * Input parameter:                                                     *
 *      rimnem[]        char            Interface mnemonics for reals   *
 *      cimnem[]        char            Interface mnemonics for chars   *
 *                                                                      *
 * Output parameter:                                                    *
 *      *ret            int             Return code                     *
 *                                         0 = normal return            *
 *                                                                      *
 **                                                                     *
 *Log:                                                                  *
 * R. Hollern/NCEP      2/2000                                          *
/***********************************************************************/

void ma_icpt( char rimnem[][8], char cimnem[][8], int *iret )

{
    int ierwlg;

    unsigned int jj, nclo, ncwd, nswv, nspw, npcv;

    char logmsg[201];

/*
**  Print out all of the single-level character interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NCIMN; jj++ ) {
	if ( cintfv.civals[jj][0] != CHSPAC ) {
	    sprintf( logmsg, "%s = ", outstr(cimnem[jj]) );
	    sprintf( &(logmsg[strlen(logmsg)]), "%s\n" ,
		     outstr(cintfv.civals[jj]) );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the single-level real interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NRSLMN; jj++ ) {
	if ( ! ERMISS( rintfv.rivals[jj] ) ) {
	    sprintf( logmsg, "%s = %10.2f\n",
		     outstr(rimnem[jj]), rintfv.rivals[jj] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the multi-level interface values.
*/

/*
**  Cloud data.
*/
       nclo = ( unsigned int ) rintfv.rivals[(rintfp.irnclo)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irnclo)-1]), nclo );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( nclo > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irvsso[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irclam[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.ircltp[0])-1]) );
	 strcpy( &(logmsg[24]), outstr(rimnem[(rintfp.irhocb[0])-1]) );
	 strcpy( &(logmsg[32]), outstr(rimnem[(rintfp.ircsec[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < nclo; jj++ ) {
	    sprintf( logmsg,
		     "%5.1f %5.1f %8.1f %8.1f %5.1f\n",
		     rintfv.rivals[(rintfp.irvsso[jj])-1],
		     rintfv.rivals[(rintfp.irclam[jj])-1],
		     rintfv.rivals[(rintfp.ircltp[jj])-1],
		     rintfv.rivals[(rintfp.irhocb[jj])-1],
		     rintfv.rivals[(rintfp.ircsec[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
      }

/*
**  Precipitation data.
*/
       npcv = ( unsigned int ) rintfv.rivals[(rintfp.irnpcv)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irnpcv)-1]), npcv );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( npcv > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irpprd[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irpamt[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < npcv; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irpprd[jj])-1],
		     rintfv.rivals[(rintfp.irpamt[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
       }

/*
**  Supplementary wind data.
*/
       nspw = ( unsigned int ) rintfv.rivals[(rintfp.irnspw)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irnspw)-1]), nspw );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( nspw > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irspwp[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irspws[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.irspwt[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < nspw; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irspwp[jj])-1],
		     rintfv.rivals[(rintfp.irspws[jj])-1],
		     rintfv.rivals[(rintfp.irspwt[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
       }

/*
**  Continuous wind data.   
*/
       ncwd = ( unsigned int ) rintfv.rivals[(rintfp.irncwd)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irncwd)-1]), ncwd );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( ncwd > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irtpmi[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irwdrc[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.irwdsc[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < ncwd; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irtpmi[jj])-1],
		     rintfv.rivals[(rintfp.irwdrc[jj])-1],
		     rintfv.rivals[(rintfp.irwdsc[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
       }

/*
**  Wave data.              
*/
       nswv = ( unsigned int ) rintfv.rivals[(rintfp.irnswv)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irnswv)-1]), nswv );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( nswv > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irdosw[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irposw[0])-1]) );
	 strcpy( &(logmsg[16]),  outstr(rimnem[(rintfp.irhosw[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < nswv; jj++ ) {
	    sprintf( logmsg,
		     "%8.2f %8.2f %8.2f\n",
		     rintfv.rivals[(rintfp.irdosw[jj])-1],
		     rintfv.rivals[(rintfp.irposw[jj])-1],
		     rintfv.rivals[(rintfp.irhosw[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
       }

/*
**  Set return code.
*/
    *iret = 0;

    return;
}

char *outstr( char string[] ) {

    unsigned short ii;

    static char tmpstr[9];

/*
**  Return a null-terminated copy of string.
*/
    for ( ii = 0; ii < 8; ii++ ) {
	tmpstr[ii] = string[ii];
    }
    tmpstr[8] = '\0';

    return tmpstr;
}
