        SUBROUTINE MA_SPWD  ( iparam, wdspd, iret )
C************************************************************************
C* MA_SPWD                                                              *
C*                                                                      *
C* This subroutine stores in the interface variables the supplementary  *
C* wind data obtained from the groups 910ff, 911ff, and 912ff and the   *
C* duration of the periods of these wind data.  The periods are obtained*
C* from the supplementary 907tt group(s) or computed from the hour of   *
C* the observation.                                                     *
C*                                                                      *
C* MA_SPWD  ( IPARAM, WDSPD, IRET )                                     *
C*                                                                      *
C* Input parameters:                                                    *
C*      IPARAM 		INTEGER         Flag set to 1, 2, or 5 to refer,*
C*                                      respectively, to the group      *
C*                                      910ff, 912ff, or 911ff          *
C*      IBRTYP          INTEGER         Bulletin report type            *
C*                                        1 = BBXX reports              *
C*                                        2 = CMAN reports              *
C*      WDSPD           INTEGER         Wind speed in m/sec             *
C*      IFBUOY          INTEGER         FLAG set to 1 if ship report    *
C*      XM907		REAL		Duration in minutes of wind     *
C*					gust period                     *
C*      MXSPWL          INTEGER         Maximum number of layers of     *
C*                                      supplementary wind data         *
C*					                                *
C* Output parameters:                                                   *
C*      RIVALS(IRNSPW)  REAL		Number of supplementary wind    *
C*                                      groups                          *
C*      RIVALS(IRSPWP)  REAL            Duration in minutes of wind     *
C*                                      periods                         *
C*	RIVALS(IRSPWS)  REAL            Supplementary winds in m/sec    *
C*	RIVALS(IRSPWT)  REAL            NCEP Code Table to indicate     *
C*	                                whether gust from 910ff, 911ff, *
C*	                                or 912ff group                  *
C*	IRET            INTEGER         Return code                     *
C*				   	  0 = Normal return 	        *
C*                                        1 = Problems                  *
C*                                                                      *
C**								        *
C* Log:							                *
C* R. Hollern/NCEP     11/99                                            *
C************************************************************************
        INCLUDE 	'GEMPRM.PRM'
        INCLUDE 	'macmn.cmn'
C*
        INCLUDE 'ERMISS.FNC'
C------------------------------------------------------------------------
        iret = 0
C
C*      Compute the number of supplementary wind groups.
C
        ispwds = ispwds + 1
        IF ( ispwds .le. MXSPWL ) THEN
            rivals ( irnspw ) = FLOAT ( ispwds )
        ELSE
            RETURN
        END IF
        
        IF ( iparam .eq. 1 ) THEN
C
            rivals ( irspwp ( ispwds ) ) = 10.
            rivals ( irspws ( ispwds ) ) = wdspd
            rivals ( irspwt ( ispwds ) ) = 1.0
            RETURN
        END IF
C
C*      Determine the period for the 911ff and 912ff groups using
C*      the period for the W(1)W(2) in the 7wwW(1)W(2) group.  This
C*      period will be used if the period from the 907tt group
C*      is missing.
C
        irem1 = MOD ( ihour, 6 )
        irem2 = MOD ( ihour, 3 )
C
        IF ( irem1 .eq. 0 ) THEN
            xper = 360.0
          ELSE IF ( irem2 .eq. 0 ) THEN
            xper = 180.0
          ELSE
            xper = 120.0
        END IF
C
        IF ( iparam .eq. 2 ) THEN
            rivals ( irspws ( ispwds ) ) = wdspd
            rivals ( irspwt ( ispwds ) ) = 2.0
            IF ( .NOT. ERMISS ( xm907 ) ) THEN
                rivals ( irspwp ( ispwds ) ) = xm907
                xm907 = RMISSD
              ELSE
                IF ( ifbuoy .eq. 1 .and. ibrtyp .eq. 1 ) THEN
C
C*                  Ship report.
C
                    rivals ( irspwp ( ispwds ) ) = xper
                  ELSE
C
C*                  Fixed buoy or CMAN report.
C
                    rivals ( irspwp ( ispwds ) ) = 0.0
                END IF
            END IF
          ELSE IF ( iparam .eq. 5 ) THEN
            rivals ( irspws ( ispwds ) ) = wdspd
            rivals ( irspwt ( ispwds ) ) = 0.0
            IF ( .NOT. ERMISS ( xm907 ) ) THEN
                rivals ( irspwp ( ispwds ) ) = xm907
                xm907 = RMISSD
              ELSE
                IF ( ifbuoy .eq. 1 .and. ibrtyp .eq. 1 ) THEN
                    rivals ( irspwp ( ispwds ) ) = xper
                  ELSE
                    rivals ( irspwp ( ispwds ) ) = 0.0
                END IF
            END IF
        END IF
C*
        RETURN
        END
